summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorxhwang@chromium.org <xhwang@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-04 06:11:09 +0000
committerxhwang@chromium.org <xhwang@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-04 06:11:09 +0000
commit1561fa831a20df80b9ae5aaecf7e07e184176387 (patch)
treed01cdb23b1916e43565274383a0483f75940f060
parent4c34dee16bef0f9c15cad7e794dafde0db27ba5e (diff)
downloadchromium_src-1561fa831a20df80b9ae5aaecf7e07e184176387.zip
chromium_src-1561fa831a20df80b9ae5aaecf7e07e184176387.tar.gz
chromium_src-1561fa831a20df80b9ae5aaecf7e07e184176387.tar.bz2
Encrypted Media: Use uint32 for systemCode in SessionError.
In prefixed EME spec, "systemCode" is an unsigned short (16bit unsigned integer). In unprefixed EME spec, it's an unsigned long (32bit unsigned integer). This CL updates "system_code" parameters in SessionError to use uint32. TBR=dcheng@chromium.org BUG=224786 Review URL: https://codereview.chromium.org/179123009 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@254693 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--content/browser/media/android/browser_media_player_manager.cc2
-rw-r--r--content/browser/media/android/browser_media_player_manager.h2
-rw-r--r--content/common/media/cdm_messages.h2
-rw-r--r--content/renderer/media/android/proxy_media_keys.cc2
-rw-r--r--content/renderer/media/android/proxy_media_keys.h2
-rw-r--r--content/renderer/media/android/renderer_media_player_manager.cc2
-rw-r--r--content/renderer/media/android/renderer_media_player_manager.h2
-rw-r--r--content/renderer/media/android/webmediaplayer_android.cc12
-rw-r--r--content/renderer/media/android/webmediaplayer_android.h2
-rw-r--r--content/renderer/media/cdm_session_adapter.cc2
-rw-r--r--content/renderer/media/cdm_session_adapter.h2
-rw-r--r--content/renderer/media/crypto/ppapi_decryptor.cc2
-rw-r--r--content/renderer/media/crypto/ppapi_decryptor.h2
-rw-r--r--content/renderer/media/crypto/proxy_decryptor.cc2
-rw-r--r--content/renderer/media/crypto/proxy_decryptor.h4
-rw-r--r--content/renderer/media/webcontentdecryptionmodulesession_impl.cc2
-rw-r--r--content/renderer/media/webcontentdecryptionmodulesession_impl.h3
-rw-r--r--content/renderer/media/webmediaplayer_impl.cc12
-rw-r--r--content/renderer/media/webmediaplayer_impl.h2
-rw-r--r--content/renderer/pepper/content_decryptor_delegate.cc2
-rw-r--r--content/renderer/pepper/content_decryptor_delegate.h2
-rw-r--r--content/renderer/pepper/pepper_plugin_instance_impl.cc2
-rw-r--r--content/renderer/pepper/pepper_plugin_instance_impl.h2
-rw-r--r--media/base/android/media_player_manager.h2
-rw-r--r--media/base/android/media_source_player_unittest.cc2
-rw-r--r--media/base/media_keys.h2
-rw-r--r--media/cdm/aes_decryptor_unittest.cc4
-rw-r--r--media/cdm/ppapi/external_clear_key/clear_key_cdm.cc2
-rw-r--r--media/cdm/ppapi/external_clear_key/clear_key_cdm.h2
-rw-r--r--media/filters/pipeline_integration_test.cc4
-rw-r--r--ppapi/api/private/ppb_content_decryptor_private.idl4
-rw-r--r--ppapi/c/pp_macros.h4
-rw-r--r--ppapi/c/private/ppb_content_decryptor_private.h14
-rw-r--r--ppapi/cpp/private/content_decryptor_private.cc2
-rw-r--r--ppapi/cpp/private/content_decryptor_private.h2
-rw-r--r--ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c82
-rw-r--r--ppapi/proxy/ppb_instance_proxy.cc6
-rw-r--r--ppapi/proxy/ppb_instance_proxy.h4
-rw-r--r--ppapi/thunk/interfaces_ppb_private.h4
-rw-r--r--ppapi/thunk/ppb_content_decryptor_private_thunk.cc14
-rw-r--r--ppapi/thunk/ppb_instance_api.h12
-rw-r--r--tools/metrics/histograms/histograms.xml2
42 files changed, 128 insertions, 109 deletions
diff --git a/content/browser/media/android/browser_media_player_manager.cc b/content/browser/media/android/browser_media_player_manager.cc
index 404168c..a8ffa3a 100644
--- a/content/browser/media/android/browser_media_player_manager.cc
+++ b/content/browser/media/android/browser_media_player_manager.cc
@@ -413,7 +413,7 @@ void BrowserMediaPlayerManager::OnSessionError(
int cdm_id,
uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
Send(new CdmMsg_SessionError(
routing_id(), cdm_id, session_id, error_code, system_code));
}
diff --git a/content/browser/media/android/browser_media_player_manager.h b/content/browser/media/android/browser_media_player_manager.h
index 37654c1..9209114 100644
--- a/content/browser/media/android/browser_media_player_manager.h
+++ b/content/browser/media/android/browser_media_player_manager.h
@@ -104,7 +104,7 @@ class CONTENT_EXPORT BrowserMediaPlayerManager
virtual void OnSessionError(int cdm_id,
uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) OVERRIDE;
+ uint32 system_code) OVERRIDE;
#if defined(VIDEO_HOLE)
void AttachExternalVideoSurface(int player_id, jobject surface);
diff --git a/content/common/media/cdm_messages.h b/content/common/media/cdm_messages.h
index 2dd9cb6..2d796de 100644
--- a/content/common/media/cdm_messages.h
+++ b/content/common/media/cdm_messages.h
@@ -67,4 +67,4 @@ IPC_MESSAGE_ROUTED4(CdmMsg_SessionError,
int /* cdm_id */,
uint32_t /* session_id */,
media::MediaKeys::KeyError /* error_code */,
- int /* system_code */)
+ uint32_t /* system_code */)
diff --git a/content/renderer/media/android/proxy_media_keys.cc b/content/renderer/media/android/proxy_media_keys.cc
index f6a07c5..5510950 100644
--- a/content/renderer/media/android/proxy_media_keys.cc
+++ b/content/renderer/media/android/proxy_media_keys.cc
@@ -113,7 +113,7 @@ void ProxyMediaKeys::OnSessionClosed(uint32 session_id) {
void ProxyMediaKeys::OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
session_error_cb_.Run(session_id, error_code, system_code);
}
diff --git a/content/renderer/media/android/proxy_media_keys.h b/content/renderer/media/android/proxy_media_keys.h
index ac54960..dd0f99e 100644
--- a/content/renderer/media/android/proxy_media_keys.h
+++ b/content/renderer/media/android/proxy_media_keys.h
@@ -52,7 +52,7 @@ class ProxyMediaKeys : public media::MediaKeys {
void OnSessionClosed(uint32 session_id);
void OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
private:
RendererMediaPlayerManager* manager_;
diff --git a/content/renderer/media/android/renderer_media_player_manager.cc b/content/renderer/media/android/renderer_media_player_manager.cc
index 54c9eac..f61c096 100644
--- a/content/renderer/media/android/renderer_media_player_manager.cc
+++ b/content/renderer/media/android/renderer_media_player_manager.cc
@@ -318,7 +318,7 @@ void RendererMediaPlayerManager::OnSessionError(
int cdm_id,
uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
ProxyMediaKeys* media_keys = GetMediaKeys(cdm_id);
if (media_keys)
media_keys->OnSessionError(session_id, error_code, system_code);
diff --git a/content/renderer/media/android/renderer_media_player_manager.h b/content/renderer/media/android/renderer_media_player_manager.h
index d0b572b..851da32 100644
--- a/content/renderer/media/android/renderer_media_player_manager.h
+++ b/content/renderer/media/android/renderer_media_player_manager.h
@@ -175,7 +175,7 @@ class RendererMediaPlayerManager : public RenderViewObserver {
void OnSessionError(int cdm_id,
uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
// Info for all available WebMediaPlayerAndroid on a page; kept so that
// we can enumerate them to send updates about tab focus and visibility.
diff --git a/content/renderer/media/android/webmediaplayer_android.cc b/content/renderer/media/android/webmediaplayer_android.cc
index 6fae70c..9a87ecfd 100644
--- a/content/renderer/media/android/webmediaplayer_android.cc
+++ b/content/renderer/media/android/webmediaplayer_android.cc
@@ -1332,15 +1332,23 @@ void WebMediaPlayerAndroid::OnKeyAdded(const std::string& session_id) {
void WebMediaPlayerAndroid::OnKeyError(const std::string& session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
EmeUMAHistogramEnumeration(current_key_system_, "KeyError",
error_code, media::MediaKeys::kMaxKeyError);
+ unsigned short short_system_code = 0;
+ if (system_code > std::numeric_limits<unsigned short>::max()) {
+ LOG(WARNING) << "system_code exceeds unsigned short limit.";
+ short_system_code = std::numeric_limits<unsigned short>::max();
+ } else {
+ short_system_code = static_cast<unsigned short>(system_code);
+ }
+
client_->keyError(
WebString::fromUTF8(GetPrefixedKeySystemName(current_key_system_)),
WebString::fromUTF8(session_id),
static_cast<blink::WebMediaPlayerClient::MediaKeyErrorCode>(error_code),
- system_code);
+ short_system_code);
}
void WebMediaPlayerAndroid::OnKeyMessage(const std::string& session_id,
diff --git a/content/renderer/media/android/webmediaplayer_android.h b/content/renderer/media/android/webmediaplayer_android.h
index 8d70342..012e24e 100644
--- a/content/renderer/media/android/webmediaplayer_android.h
+++ b/content/renderer/media/android/webmediaplayer_android.h
@@ -220,7 +220,7 @@ class WebMediaPlayerAndroid
void OnKeyAdded(const std::string& session_id);
void OnKeyError(const std::string& session_id,
media::MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
void OnKeyMessage(const std::string& session_id,
const std::vector<uint8>& message,
const std::string& destination_url);
diff --git a/content/renderer/media/cdm_session_adapter.cc b/content/renderer/media/cdm_session_adapter.cc
index 0850694..b77cb38 100644
--- a/content/renderer/media/cdm_session_adapter.cc
+++ b/content/renderer/media/cdm_session_adapter.cc
@@ -129,7 +129,7 @@ void CdmSessionAdapter::OnSessionClosed(uint32 session_id) {
void CdmSessionAdapter::OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
WebContentDecryptionModuleSessionImpl* session = GetSession(session_id);
DLOG_IF(WARNING, !session) << __FUNCTION__ << " for unknown session "
<< session_id;
diff --git a/content/renderer/media/cdm_session_adapter.h b/content/renderer/media/cdm_session_adapter.h
index f6f2930..611f25b 100644
--- a/content/renderer/media/cdm_session_adapter.h
+++ b/content/renderer/media/cdm_session_adapter.h
@@ -80,7 +80,7 @@ class CdmSessionAdapter : public base::RefCounted<CdmSessionAdapter> {
void OnSessionClosed(uint32 session_id);
void OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
// Helper function of the callbacks.
WebContentDecryptionModuleSessionImpl* GetSession(uint32 session_id);
diff --git a/content/renderer/media/crypto/ppapi_decryptor.cc b/content/renderer/media/crypto/ppapi_decryptor.cc
index 4ae3686..b4e8b07 100644
--- a/content/renderer/media/crypto/ppapi_decryptor.cc
+++ b/content/renderer/media/crypto/ppapi_decryptor.cc
@@ -365,7 +365,7 @@ void PpapiDecryptor::OnSessionClosed(uint32 session_id) {
void PpapiDecryptor::OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
DCHECK(render_loop_proxy_->BelongsToCurrentThread());
session_error_cb_.Run(session_id, error_code, system_code);
}
diff --git a/content/renderer/media/crypto/ppapi_decryptor.h b/content/renderer/media/crypto/ppapi_decryptor.h
index 64b45d9..0fb5c1d 100644
--- a/content/renderer/media/crypto/ppapi_decryptor.h
+++ b/content/renderer/media/crypto/ppapi_decryptor.h
@@ -95,7 +95,7 @@ class PpapiDecryptor : public media::MediaKeys, public media::Decryptor {
void OnSessionClosed(uint32 session_id);
void OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
// Callback to notify that a fatal error happened in |plugin_cdm_delegate_|.
// The error is terminal and |plugin_cdm_delegate_| should not be used after
diff --git a/content/renderer/media/crypto/proxy_decryptor.cc b/content/renderer/media/crypto/proxy_decryptor.cc
index b052f15..1040810 100644
--- a/content/renderer/media/crypto/proxy_decryptor.cc
+++ b/content/renderer/media/crypto/proxy_decryptor.cc
@@ -240,7 +240,7 @@ void ProxyDecryptor::OnSessionClosed(uint32 session_id) {
void ProxyDecryptor::OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
// Assumes that OnSessionCreated() has been called before this.
key_error_cb_.Run(LookupWebSessionId(session_id), error_code, system_code);
}
diff --git a/content/renderer/media/crypto/proxy_decryptor.h b/content/renderer/media/crypto/proxy_decryptor.h
index 3f5ceeb..9815666 100644
--- a/content/renderer/media/crypto/proxy_decryptor.h
+++ b/content/renderer/media/crypto/proxy_decryptor.h
@@ -49,7 +49,7 @@ class ProxyDecryptor {
typedef base::Callback<void(const std::string& session_id)> KeyAddedCB;
typedef base::Callback<void(const std::string& session_id,
media::MediaKeys::KeyError error_code,
- int system_code)> KeyErrorCB;
+ uint32 system_code)> KeyErrorCB;
typedef base::Callback<void(const std::string& session_id,
const std::vector<uint8>& message,
const std::string& default_url)> KeyMessageCB;
@@ -99,7 +99,7 @@ class ProxyDecryptor {
void OnSessionClosed(uint32 session_id);
void OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
// Helper function to determine session_id for the provided |web_session_id|.
uint32 LookupSessionId(const std::string& web_session_id) const;
diff --git a/content/renderer/media/webcontentdecryptionmodulesession_impl.cc b/content/renderer/media/webcontentdecryptionmodulesession_impl.cc
index 6a3935e..f46e247 100644
--- a/content/renderer/media/webcontentdecryptionmodulesession_impl.cc
+++ b/content/renderer/media/webcontentdecryptionmodulesession_impl.cc
@@ -86,7 +86,7 @@ void WebContentDecryptionModuleSessionImpl::OnSessionClosed() {
void WebContentDecryptionModuleSessionImpl::OnSessionError(
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
client_->error(static_cast<Client::MediaKeyErrorCode>(error_code),
system_code);
}
diff --git a/content/renderer/media/webcontentdecryptionmodulesession_impl.h b/content/renderer/media/webcontentdecryptionmodulesession_impl.h
index 53488cb..add26ca 100644
--- a/content/renderer/media/webcontentdecryptionmodulesession_impl.h
+++ b/content/renderer/media/webcontentdecryptionmodulesession_impl.h
@@ -45,7 +45,8 @@ class WebContentDecryptionModuleSessionImpl
const std::string& destination_url);
void OnSessionReady();
void OnSessionClosed();
- void OnSessionError(media::MediaKeys::KeyError error_code, int system_code);
+ void OnSessionError(media::MediaKeys::KeyError error_code,
+ uint32 system_code);
private:
scoped_refptr<CdmSessionAdapter> adapter_;
diff --git a/content/renderer/media/webmediaplayer_impl.cc b/content/renderer/media/webmediaplayer_impl.cc
index 411b814..b11a21f 100644
--- a/content/renderer/media/webmediaplayer_impl.cc
+++ b/content/renderer/media/webmediaplayer_impl.cc
@@ -1062,17 +1062,25 @@ void WebMediaPlayerImpl::OnAddTextTrack(
void WebMediaPlayerImpl::OnKeyError(const std::string& session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
DCHECK(main_loop_->BelongsToCurrentThread());
EmeUMAHistogramEnumeration(current_key_system_, "KeyError",
error_code, media::MediaKeys::kMaxKeyError);
+ unsigned short short_system_code = 0;
+ if (system_code > std::numeric_limits<unsigned short>::max()) {
+ LOG(WARNING) << "system_code exceeds unsigned short limit.";
+ short_system_code = std::numeric_limits<unsigned short>::max();
+ } else {
+ short_system_code = static_cast<unsigned short>(system_code);
+ }
+
client_->keyError(
WebString::fromUTF8(GetPrefixedKeySystemName(current_key_system_)),
WebString::fromUTF8(session_id),
static_cast<blink::WebMediaPlayerClient::MediaKeyErrorCode>(error_code),
- system_code);
+ short_system_code);
}
void WebMediaPlayerImpl::OnKeyMessage(const std::string& session_id,
diff --git a/content/renderer/media/webmediaplayer_impl.h b/content/renderer/media/webmediaplayer_impl.h
index 22a6c83..7f765a8 100644
--- a/content/renderer/media/webmediaplayer_impl.h
+++ b/content/renderer/media/webmediaplayer_impl.h
@@ -180,7 +180,7 @@ class WebMediaPlayerImpl
void OnKeyAdded(const std::string& session_id);
void OnKeyError(const std::string& session_id,
media::MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
void OnKeyMessage(const std::string& session_id,
const std::vector<uint8>& message,
const std::string& default_url);
diff --git a/content/renderer/pepper/content_decryptor_delegate.cc b/content/renderer/pepper/content_decryptor_delegate.cc
index f9747a0..53ff21b 100644
--- a/content/renderer/pepper/content_decryptor_delegate.cc
+++ b/content/renderer/pepper/content_decryptor_delegate.cc
@@ -627,7 +627,7 @@ void ContentDecryptorDelegate::OnSessionClosed(uint32 session_id) {
void ContentDecryptorDelegate::OnSessionError(uint32 session_id,
int32_t media_error,
- int32_t system_code) {
+ uint32_t system_code) {
if (session_error_cb_.is_null())
return;
diff --git a/content/renderer/pepper/content_decryptor_delegate.h b/content/renderer/pepper/content_decryptor_delegate.h
index f643d41..c45351e 100644
--- a/content/renderer/pepper/content_decryptor_delegate.h
+++ b/content/renderer/pepper/content_decryptor_delegate.h
@@ -92,7 +92,7 @@ class ContentDecryptorDelegate {
void OnSessionClosed(uint32 session_id);
void OnSessionError(uint32 session_id,
int32_t media_error,
- int32_t system_code);
+ uint32_t system_code);
void DeliverBlock(PP_Resource decrypted_block,
const PP_DecryptedBlockInfo* block_info);
void DecoderInitializeDone(PP_DecryptorStreamType decoder_type,
diff --git a/content/renderer/pepper/pepper_plugin_instance_impl.cc b/content/renderer/pepper/pepper_plugin_instance_impl.cc
index eca0c13..72d9d2a 100644
--- a/content/renderer/pepper/pepper_plugin_instance_impl.cc
+++ b/content/renderer/pepper/pepper_plugin_instance_impl.cc
@@ -2367,7 +2367,7 @@ void PepperPluginInstanceImpl::SessionClosed(PP_Instance instance,
void PepperPluginInstanceImpl::SessionError(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_code) {
+ uint32_t system_code) {
content_decryptor_delegate_->OnSessionError(
session_id, media_error, system_code);
}
diff --git a/content/renderer/pepper/pepper_plugin_instance_impl.h b/content/renderer/pepper/pepper_plugin_instance_impl.h
index 5296262..c113139 100644
--- a/content/renderer/pepper/pepper_plugin_instance_impl.h
+++ b/content/renderer/pepper/pepper_plugin_instance_impl.h
@@ -464,7 +464,7 @@ class CONTENT_EXPORT PepperPluginInstanceImpl
virtual void SessionError(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_code) OVERRIDE;
+ uint32_t system_code) OVERRIDE;
virtual void DeliverBlock(PP_Instance instance,
PP_Resource decrypted_block,
const PP_DecryptedBlockInfo* block_info) OVERRIDE;
diff --git a/media/base/android/media_player_manager.h b/media/base/android/media_player_manager.h
index 1dc609c..f4fe548 100644
--- a/media/base/android/media_player_manager.h
+++ b/media/base/android/media_player_manager.h
@@ -103,7 +103,7 @@ class MEDIA_EXPORT MediaPlayerManager {
virtual void OnSessionError(int cdm_id,
uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) = 0;
+ uint32 system_code) = 0;
};
} // namespace media
diff --git a/media/base/android/media_source_player_unittest.cc b/media/base/android/media_source_player_unittest.cc
index bb8e1dc2..1273ecb 100644
--- a/media/base/android/media_source_player_unittest.cc
+++ b/media/base/android/media_source_player_unittest.cc
@@ -88,7 +88,7 @@ class MockMediaPlayerManager : public MediaPlayerManager {
virtual void OnSessionError(int cdm_id,
uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) OVERRIDE {}
+ uint32 system_code) OVERRIDE {}
bool playback_completed() const {
return playback_completed_;
diff --git a/media/base/media_keys.h b/media/base/media_keys.h
index 84c1401..a6ef64ce 100644
--- a/media/base/media_keys.h
+++ b/media/base/media_keys.h
@@ -93,7 +93,7 @@ typedef base::Callback<void(uint32 session_id)> SessionClosedCB;
typedef base::Callback<void(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code)> SessionErrorCB;
+ uint32 system_code)> SessionErrorCB;
} // namespace media
diff --git a/media/cdm/aes_decryptor_unittest.cc b/media/cdm/aes_decryptor_unittest.cc
index 6b5c0dc..39a5036 100644
--- a/media/cdm/aes_decryptor_unittest.cc
+++ b/media/cdm/aes_decryptor_unittest.cc
@@ -332,7 +332,9 @@ class AesDecryptorTest : public testing::Test {
MOCK_METHOD1(OnSessionReady, void(uint32 session_id));
MOCK_METHOD1(OnSessionClosed, void(uint32 session_id));
MOCK_METHOD3(OnSessionError,
- void(uint32 session_id, MediaKeys::KeyError, int system_code));
+ void(uint32 session_id,
+ MediaKeys::KeyError,
+ uint32 system_code));
AesDecryptor decryptor_;
AesDecryptor::DecryptCB decrypt_cb_;
diff --git a/media/cdm/ppapi/external_clear_key/clear_key_cdm.cc b/media/cdm/ppapi/external_clear_key/clear_key_cdm.cc
index 64e0158..e98db7c 100644
--- a/media/cdm/ppapi/external_clear_key/clear_key_cdm.cc
+++ b/media/cdm/ppapi/external_clear_key/clear_key_cdm.cc
@@ -592,7 +592,7 @@ void ClearKeyCdm::OnSessionClosed(uint32 session_id) {
void ClearKeyCdm::OnSessionError(uint32 session_id,
media::MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
host_->OnSessionError(
session_id, static_cast<cdm::MediaKeyError>(error_code), system_code);
}
diff --git a/media/cdm/ppapi/external_clear_key/clear_key_cdm.h b/media/cdm/ppapi/external_clear_key/clear_key_cdm.h
index a79d62b..cef59db 100644
--- a/media/cdm/ppapi/external_clear_key/clear_key_cdm.h
+++ b/media/cdm/ppapi/external_clear_key/clear_key_cdm.h
@@ -81,7 +81,7 @@ class ClearKeyCdm : public ClearKeyCdmInterface {
void OnSessionClosed(uint32 session_id);
void OnSessionError(uint32 session_id,
MediaKeys::KeyError error_code,
- int system_code);
+ uint32 system_code);
// Prepares next heartbeat message and sets a timer for it.
void ScheduleNextHeartBeat();
diff --git a/media/filters/pipeline_integration_test.cc b/media/filters/pipeline_integration_test.cc
index c122ca6..ff846d6 100644
--- a/media/filters/pipeline_integration_test.cc
+++ b/media/filters/pipeline_integration_test.cc
@@ -93,7 +93,7 @@ class FakeEncryptedMedia {
// Errors are not expected unless overridden.
virtual void OnSessionError(uint32 session_id,
MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
FAIL() << "Unexpected Key Error";
}
@@ -140,7 +140,7 @@ class FakeEncryptedMedia {
void OnSessionError(uint32 session_id,
MediaKeys::KeyError error_code,
- int system_code) {
+ uint32 system_code) {
app_->OnSessionError(session_id, error_code, system_code);
}
diff --git a/ppapi/api/private/ppb_content_decryptor_private.idl b/ppapi/api/private/ppb_content_decryptor_private.idl
index f022b7d..381a0aa 100644
--- a/ppapi/api/private/ppb_content_decryptor_private.idl
+++ b/ppapi/api/private/ppb_content_decryptor_private.idl
@@ -12,7 +12,7 @@
[generate_thunk]
label Chrome {
- M34 = 0.10
+ M35 = 0.11
};
/**
@@ -114,7 +114,7 @@ interface PPB_ContentDecryptor_Private {
[in] PP_Instance instance,
[in] uint32_t session_id,
[in] int32_t media_error,
- [in] int32_t system_code);
+ [in] uint32_t system_code);
/**
* Called after the <code>Decrypt()</code> method on the
diff --git a/ppapi/c/pp_macros.h b/ppapi/c/pp_macros.h
index ebcdc78..61be3d0 100644
--- a/ppapi/c/pp_macros.h
+++ b/ppapi/c/pp_macros.h
@@ -3,13 +3,13 @@
* found in the LICENSE file.
*/
-/* From pp_macros.idl modified Mon Oct 21 10:49:59 2013. */
+/* From pp_macros.idl modified Wed Feb 26 15:01:03 2014. */
#ifndef PPAPI_C_PP_MACROS_H_
#define PPAPI_C_PP_MACROS_H_
-#define PPAPI_RELEASE 34
+#define PPAPI_RELEASE 35
/**
* @file
diff --git a/ppapi/c/private/ppb_content_decryptor_private.h b/ppapi/c/private/ppb_content_decryptor_private.h
index 3018bfb..c0c9aea7e 100644
--- a/ppapi/c/private/ppb_content_decryptor_private.h
+++ b/ppapi/c/private/ppb_content_decryptor_private.h
@@ -4,7 +4,7 @@
*/
/* From private/ppb_content_decryptor_private.idl,
- * modified Wed Jan 8 16:02:43 2014.
+ * modified Wed Feb 26 16:37:47 2014.
*/
#ifndef PPAPI_C_PRIVATE_PPB_CONTENT_DECRYPTOR_PRIVATE_H_
@@ -18,10 +18,10 @@
#include "ppapi/c/pp_var.h"
#include "ppapi/c/private/pp_content_decryptor.h"
-#define PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_10 \
- "PPB_ContentDecryptor_Private;0.10"
+#define PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_11 \
+ "PPB_ContentDecryptor_Private;0.11"
#define PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE \
- PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_10
+ PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_11
/**
* @file
@@ -42,7 +42,7 @@
* browser side support for the Content Decryption Module (CDM) for Encrypted
* Media Extensions: http://www.w3.org/TR/encrypted-media/
*/
-struct PPB_ContentDecryptor_Private_0_10 {
+struct PPB_ContentDecryptor_Private_0_11 {
/**
* A session has been created by the CDM.
*
@@ -123,7 +123,7 @@ struct PPB_ContentDecryptor_Private_0_10 {
void (*SessionError)(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_code);
+ uint32_t system_code);
/**
* Called after the <code>Decrypt()</code> method on the
* <code>PPP_ContentDecryptor_Private</code> interface completes to
@@ -253,7 +253,7 @@ struct PPB_ContentDecryptor_Private_0_10 {
const struct PP_DecryptedSampleInfo* decrypted_sample_info);
};
-typedef struct PPB_ContentDecryptor_Private_0_10 PPB_ContentDecryptor_Private;
+typedef struct PPB_ContentDecryptor_Private_0_11 PPB_ContentDecryptor_Private;
/**
* @}
*/
diff --git a/ppapi/cpp/private/content_decryptor_private.cc b/ppapi/cpp/private/content_decryptor_private.cc
index 7cad0a3..bed411a 100644
--- a/ppapi/cpp/private/content_decryptor_private.cc
+++ b/ppapi/cpp/private/content_decryptor_private.cc
@@ -264,7 +264,7 @@ void ContentDecryptor_Private::SessionClosed(uint32_t session_id) {
void ContentDecryptor_Private::SessionError(uint32_t session_id,
int32_t media_error,
- int32_t system_code) {
+ uint32_t system_code) {
if (has_interface<PPB_ContentDecryptor_Private>()) {
get_interface<PPB_ContentDecryptor_Private>()->SessionError(
associated_instance_.pp_instance(),
diff --git a/ppapi/cpp/private/content_decryptor_private.h b/ppapi/cpp/private/content_decryptor_private.h
index 4ac9f79..b392263 100644
--- a/ppapi/cpp/private/content_decryptor_private.h
+++ b/ppapi/cpp/private/content_decryptor_private.h
@@ -68,7 +68,7 @@ class ContentDecryptor_Private {
void SessionClosed(uint32_t session_id);
void SessionError(uint32_t session_id,
int32_t media_error,
- int32_t system_code);
+ uint32_t system_code);
// The plugin must not hold a reference to the encrypted buffer resource
// provided to Decrypt() when it calls this method. The browser will reuse
diff --git a/ppapi/proxy/ppb_instance_proxy.cc b/ppapi/proxy/ppb_instance_proxy.cc
index f3f6322..885b5e4 100644
--- a/ppapi/proxy/ppb_instance_proxy.cc
+++ b/ppapi/proxy/ppb_instance_proxy.cc
@@ -573,7 +573,7 @@ void PPB_Instance_Proxy::SessionClosed(PP_Instance instance,
void PPB_Instance_Proxy::SessionError(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_code) {
+ uint32_t system_code) {
dispatcher()->Send(new PpapiHostMsg_PPBInstance_SessionError(
API_ID_PPB_INSTANCE, instance, session_id, media_error, system_code));
}
@@ -1094,13 +1094,13 @@ void PPB_Instance_Proxy::OnHostMsgSessionClosed(PP_Instance instance,
void PPB_Instance_Proxy::OnHostMsgSessionError(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_error) {
+ uint32_t system_code) {
if (!dispatcher()->permissions().HasPermission(PERMISSION_PRIVATE))
return;
EnterInstanceNoLock enter(instance);
if (enter.succeeded()) {
enter.functions()->SessionError(
- instance, session_id, media_error, system_error);
+ instance, session_id, media_error, system_code);
}
}
diff --git a/ppapi/proxy/ppb_instance_proxy.h b/ppapi/proxy/ppb_instance_proxy.h
index 0737b58..c8aa49d 100644
--- a/ppapi/proxy/ppb_instance_proxy.h
+++ b/ppapi/proxy/ppb_instance_proxy.h
@@ -128,7 +128,7 @@ class PPB_Instance_Proxy : public InterfaceProxy,
virtual void SessionError(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_code) OVERRIDE;
+ uint32_t system_code) OVERRIDE;
virtual void DeliverBlock(PP_Instance instance,
PP_Resource decrypted_block,
const PP_DecryptedBlockInfo* block_info) OVERRIDE;
@@ -234,7 +234,7 @@ class PPB_Instance_Proxy : public InterfaceProxy,
virtual void OnHostMsgSessionError(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_code);
+ uint32_t system_code);
virtual void OnHostMsgDecoderInitializeDone(
PP_Instance instance,
PP_DecryptorStreamType decoder_type,
diff --git a/ppapi/thunk/interfaces_ppb_private.h b/ppapi/thunk/interfaces_ppb_private.h
index f08c279..1d2d143 100644
--- a/ppapi/thunk/interfaces_ppb_private.h
+++ b/ppapi/thunk/interfaces_ppb_private.h
@@ -23,8 +23,8 @@ PROXIED_IFACE(PPB_BROKER_TRUSTED_INTERFACE_0_3,
PPB_BrokerTrusted_0_3)
PROXIED_IFACE(PPB_BROWSERFONT_TRUSTED_INTERFACE_1_0,
PPB_BrowserFont_Trusted_1_0)
-PROXIED_IFACE(PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_10,
- PPB_ContentDecryptor_Private_0_10)
+PROXIED_IFACE(PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_11,
+ PPB_ContentDecryptor_Private_0_11)
PROXIED_IFACE(PPB_CHARSET_TRUSTED_INTERFACE_1_0,
PPB_CharSet_Trusted_1_0)
PROXIED_IFACE(PPB_FILECHOOSER_TRUSTED_INTERFACE_0_5,
diff --git a/ppapi/thunk/ppb_content_decryptor_private_thunk.cc b/ppapi/thunk/ppb_content_decryptor_private_thunk.cc
index 3af6226c..42836d9 100644
--- a/ppapi/thunk/ppb_content_decryptor_private_thunk.cc
+++ b/ppapi/thunk/ppb_content_decryptor_private_thunk.cc
@@ -3,7 +3,7 @@
// found in the LICENSE file.
// From private/ppb_content_decryptor_private.idl,
-// modified Mon Jan 13 12:02:23 2014.
+// modified Wed Feb 26 16:37:47 2014.
#include "ppapi/c/pp_errors.h"
#include "ppapi/c/private/ppb_content_decryptor_private.h"
@@ -59,7 +59,7 @@ void SessionClosed(PP_Instance instance, uint32_t session_id) {
void SessionError(PP_Instance instance,
uint32_t session_id,
int32_t media_error,
- int32_t system_code) {
+ uint32_t system_code) {
VLOG(4) << "PPB_ContentDecryptor_Private::SessionError()";
EnterInstance enter(instance);
if (enter.failed())
@@ -143,8 +143,8 @@ void DeliverSamples(
decrypted_sample_info);
}
-const PPB_ContentDecryptor_Private_0_10
- g_ppb_contentdecryptor_private_thunk_0_10 = {
+const PPB_ContentDecryptor_Private_0_11
+ g_ppb_contentdecryptor_private_thunk_0_11 = {
&SessionCreated,
&SessionMessage,
&SessionReady,
@@ -160,9 +160,9 @@ const PPB_ContentDecryptor_Private_0_10
} // namespace
-PPAPI_THUNK_EXPORT const PPB_ContentDecryptor_Private_0_10*
- GetPPB_ContentDecryptor_Private_0_10_Thunk() {
- return &g_ppb_contentdecryptor_private_thunk_0_10;
+PPAPI_THUNK_EXPORT const PPB_ContentDecryptor_Private_0_11*
+ GetPPB_ContentDecryptor_Private_0_11_Thunk() {
+ return &g_ppb_contentdecryptor_private_thunk_0_11;
}
} // namespace thunk
diff --git a/ppapi/thunk/ppb_instance_api.h b/ppapi/thunk/ppb_instance_api.h
index bac3f97..0136839 100644
--- a/ppapi/thunk/ppb_instance_api.h
+++ b/ppapi/thunk/ppb_instance_api.h
@@ -143,18 +143,18 @@ class PPB_Instance_API {
#if !defined(OS_NACL)
// Content Decryptor.
virtual void SessionCreated(PP_Instance instance,
- uint32 session_id,
+ uint32_t session_id,
PP_Var web_session_id) = 0;
virtual void SessionMessage(PP_Instance instance,
- uint32 session_id,
+ uint32_t session_id,
PP_Var message,
PP_Var destination_url) = 0;
- virtual void SessionReady(PP_Instance instance, uint32 session_id) = 0;
- virtual void SessionClosed(PP_Instance instance, uint32 session_id) = 0;
+ virtual void SessionReady(PP_Instance instance, uint32_t session_id) = 0;
+ virtual void SessionClosed(PP_Instance instance, uint32_t session_id) = 0;
virtual void SessionError(PP_Instance instance,
- uint32 session_id,
+ uint32_t session_id,
int32_t media_error,
- int32_t system_error) = 0;
+ uint32_t system_code) = 0;
virtual void DeliverBlock(PP_Instance instance,
PP_Resource decrypted_block,
const PP_DecryptedBlockInfo* block_info) = 0;
diff --git a/tools/metrics/histograms/histograms.xml b/tools/metrics/histograms/histograms.xml
index 649f522..4c01d5c 100644
--- a/tools/metrics/histograms/histograms.xml
+++ b/tools/metrics/histograms/histograms.xml
@@ -31979,7 +31979,7 @@ other types of suffix sets.
</enum>
<enum name="PepperInterface" type="int">
-<!-- Generated by ppapi/tools/pepper_hash_for_uma.cc -->
+<!-- Generated by src/ppapi/tools/pepper_hash_for_uma.cc -->
<int value="286711" label="PPB_FlashFullscreen;0.1"/>
<int value="2804066" label="PPB_AudioConfig;1.1"/>
diff --git a/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c b/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
index 13aea0a..f6b1b4f 100644
--- a/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
+++ b/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
@@ -154,7 +154,7 @@ static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_URLUtil_Dev_0_7;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_VideoCapture_Dev_0_3;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_VideoDecoder_Dev_0_16;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPP_Selection_Dev_0_3;
-static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10;
+static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_DisplayColorProfile_Private_0_1;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_Ext_CrxFileSystem_Private_0_1;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_FileIO_Private_0_1;
@@ -2433,64 +2433,64 @@ static struct PP_Var Pnacl_M13_PPP_Selection_Dev_GetSelectedText(PP_Instance ins
/* Not generating wrapper methods for PPP_Zoom_Dev_0_3 */
-/* Begin wrapper methods for PPB_ContentDecryptor_Private_0_10 */
+/* Begin wrapper methods for PPB_ContentDecryptor_Private_0_11 */
-static void Pnacl_M34_PPB_ContentDecryptor_Private_SessionCreated(PP_Instance instance, uint32_t session_id, struct PP_Var* web_session_id) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_SessionCreated(PP_Instance instance, uint32_t session_id, struct PP_Var* web_session_id) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->SessionCreated(instance, session_id, *web_session_id);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_SessionMessage(PP_Instance instance, uint32_t session_id, struct PP_Var* message, struct PP_Var* destination_url) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_SessionMessage(PP_Instance instance, uint32_t session_id, struct PP_Var* message, struct PP_Var* destination_url) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->SessionMessage(instance, session_id, *message, *destination_url);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_SessionReady(PP_Instance instance, uint32_t session_id) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_SessionReady(PP_Instance instance, uint32_t session_id) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->SessionReady(instance, session_id);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_SessionClosed(PP_Instance instance, uint32_t session_id) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_SessionClosed(PP_Instance instance, uint32_t session_id) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->SessionClosed(instance, session_id);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_SessionError(PP_Instance instance, uint32_t session_id, int32_t media_error, int32_t system_code) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_SessionError(PP_Instance instance, uint32_t session_id, int32_t media_error, uint32_t system_code) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->SessionError(instance, session_id, media_error, system_code);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_DeliverBlock(PP_Instance instance, PP_Resource decrypted_block, const struct PP_DecryptedBlockInfo* decrypted_block_info) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_DeliverBlock(PP_Instance instance, PP_Resource decrypted_block, const struct PP_DecryptedBlockInfo* decrypted_block_info) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->DeliverBlock(instance, decrypted_block, decrypted_block_info);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_DecoderInitializeDone(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id, PP_Bool success) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_DecoderInitializeDone(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id, PP_Bool success) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->DecoderInitializeDone(instance, decoder_type, request_id, success);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_DecoderDeinitializeDone(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_DecoderDeinitializeDone(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->DecoderDeinitializeDone(instance, decoder_type, request_id);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_DecoderResetDone(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_DecoderResetDone(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->DecoderResetDone(instance, decoder_type, request_id);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_DeliverFrame(PP_Instance instance, PP_Resource decrypted_frame, const struct PP_DecryptedFrameInfo* decrypted_frame_info) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_DeliverFrame(PP_Instance instance, PP_Resource decrypted_frame, const struct PP_DecryptedFrameInfo* decrypted_frame_info) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->DeliverFrame(instance, decrypted_frame, decrypted_frame_info);
}
-static void Pnacl_M34_PPB_ContentDecryptor_Private_DeliverSamples(PP_Instance instance, PP_Resource audio_frames, const struct PP_DecryptedSampleInfo* decrypted_sample_info) {
- const struct PPB_ContentDecryptor_Private_0_10 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10.real_iface;
+static void Pnacl_M35_PPB_ContentDecryptor_Private_DeliverSamples(PP_Instance instance, PP_Resource audio_frames, const struct PP_DecryptedSampleInfo* decrypted_sample_info) {
+ const struct PPB_ContentDecryptor_Private_0_11 *iface = Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11.real_iface;
iface->DeliverSamples(instance, audio_frames, decrypted_sample_info);
}
/* End wrapper methods for PPB_ContentDecryptor_Private_0_10 */
/* Begin wrapper methods for PPB_DisplayColorProfile_Private_0_1 */
@@ -4855,18 +4855,18 @@ static const struct PPP_Selection_Dev_0_3 Pnacl_Wrappers_PPP_Selection_Dev_0_3 =
/* Not generating wrapper interface for PPP_Zoom_Dev_0_3 */
-static const struct PPB_ContentDecryptor_Private_0_10 Pnacl_Wrappers_PPB_ContentDecryptor_Private_0_10 = {
- .SessionCreated = (void (*)(PP_Instance instance, uint32_t session_id, struct PP_Var web_session_id))&Pnacl_M34_PPB_ContentDecryptor_Private_SessionCreated,
- .SessionMessage = (void (*)(PP_Instance instance, uint32_t session_id, struct PP_Var message, struct PP_Var destination_url))&Pnacl_M34_PPB_ContentDecryptor_Private_SessionMessage,
- .SessionReady = (void (*)(PP_Instance instance, uint32_t session_id))&Pnacl_M34_PPB_ContentDecryptor_Private_SessionReady,
- .SessionClosed = (void (*)(PP_Instance instance, uint32_t session_id))&Pnacl_M34_PPB_ContentDecryptor_Private_SessionClosed,
- .SessionError = (void (*)(PP_Instance instance, uint32_t session_id, int32_t media_error, int32_t system_code))&Pnacl_M34_PPB_ContentDecryptor_Private_SessionError,
- .DeliverBlock = (void (*)(PP_Instance instance, PP_Resource decrypted_block, const struct PP_DecryptedBlockInfo* decrypted_block_info))&Pnacl_M34_PPB_ContentDecryptor_Private_DeliverBlock,
- .DecoderInitializeDone = (void (*)(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id, PP_Bool success))&Pnacl_M34_PPB_ContentDecryptor_Private_DecoderInitializeDone,
- .DecoderDeinitializeDone = (void (*)(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id))&Pnacl_M34_PPB_ContentDecryptor_Private_DecoderDeinitializeDone,
- .DecoderResetDone = (void (*)(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id))&Pnacl_M34_PPB_ContentDecryptor_Private_DecoderResetDone,
- .DeliverFrame = (void (*)(PP_Instance instance, PP_Resource decrypted_frame, const struct PP_DecryptedFrameInfo* decrypted_frame_info))&Pnacl_M34_PPB_ContentDecryptor_Private_DeliverFrame,
- .DeliverSamples = (void (*)(PP_Instance instance, PP_Resource audio_frames, const struct PP_DecryptedSampleInfo* decrypted_sample_info))&Pnacl_M34_PPB_ContentDecryptor_Private_DeliverSamples
+static const struct PPB_ContentDecryptor_Private_0_11 Pnacl_Wrappers_PPB_ContentDecryptor_Private_0_11 = {
+ .SessionCreated = (void (*)(PP_Instance instance, uint32_t session_id, struct PP_Var web_session_id))&Pnacl_M35_PPB_ContentDecryptor_Private_SessionCreated,
+ .SessionMessage = (void (*)(PP_Instance instance, uint32_t session_id, struct PP_Var message, struct PP_Var destination_url))&Pnacl_M35_PPB_ContentDecryptor_Private_SessionMessage,
+ .SessionReady = (void (*)(PP_Instance instance, uint32_t session_id))&Pnacl_M35_PPB_ContentDecryptor_Private_SessionReady,
+ .SessionClosed = (void (*)(PP_Instance instance, uint32_t session_id))&Pnacl_M35_PPB_ContentDecryptor_Private_SessionClosed,
+ .SessionError = (void (*)(PP_Instance instance, uint32_t session_id, int32_t media_error, uint32_t system_code))&Pnacl_M35_PPB_ContentDecryptor_Private_SessionError,
+ .DeliverBlock = (void (*)(PP_Instance instance, PP_Resource decrypted_block, const struct PP_DecryptedBlockInfo* decrypted_block_info))&Pnacl_M35_PPB_ContentDecryptor_Private_DeliverBlock,
+ .DecoderInitializeDone = (void (*)(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id, PP_Bool success))&Pnacl_M35_PPB_ContentDecryptor_Private_DecoderInitializeDone,
+ .DecoderDeinitializeDone = (void (*)(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id))&Pnacl_M35_PPB_ContentDecryptor_Private_DecoderDeinitializeDone,
+ .DecoderResetDone = (void (*)(PP_Instance instance, PP_DecryptorStreamType decoder_type, uint32_t request_id))&Pnacl_M35_PPB_ContentDecryptor_Private_DecoderResetDone,
+ .DeliverFrame = (void (*)(PP_Instance instance, PP_Resource decrypted_frame, const struct PP_DecryptedFrameInfo* decrypted_frame_info))&Pnacl_M35_PPB_ContentDecryptor_Private_DeliverFrame,
+ .DeliverSamples = (void (*)(PP_Instance instance, PP_Resource audio_frames, const struct PP_DecryptedSampleInfo* decrypted_sample_info))&Pnacl_M35_PPB_ContentDecryptor_Private_DeliverSamples
};
static const struct PPB_DisplayColorProfile_Private_0_1 Pnacl_Wrappers_PPB_DisplayColorProfile_Private_0_1 = {
@@ -5672,9 +5672,9 @@ static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPP_Selection_Dev_0_3 = {
.real_iface = NULL
};
-static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10 = {
- .iface_macro = PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_10,
- .wrapped_iface = (const void *) &Pnacl_Wrappers_PPB_ContentDecryptor_Private_0_10,
+static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11 = {
+ .iface_macro = PPB_CONTENTDECRYPTOR_PRIVATE_INTERFACE_0_11,
+ .wrapped_iface = (const void *) &Pnacl_Wrappers_PPB_ContentDecryptor_Private_0_11,
.real_iface = NULL
};
@@ -5995,7 +5995,7 @@ static struct __PnaclWrapperInfo *s_ppb_wrappers[] = {
&Pnacl_WrapperInfo_PPB_URLUtil_Dev_0_7,
&Pnacl_WrapperInfo_PPB_VideoCapture_Dev_0_3,
&Pnacl_WrapperInfo_PPB_VideoDecoder_Dev_0_16,
- &Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_10,
+ &Pnacl_WrapperInfo_PPB_ContentDecryptor_Private_0_11,
&Pnacl_WrapperInfo_PPB_DisplayColorProfile_Private_0_1,
&Pnacl_WrapperInfo_PPB_Ext_CrxFileSystem_Private_0_1,
&Pnacl_WrapperInfo_PPB_FileIO_Private_0_1,
@@ -2433,64 +2433,64 @@ static struct PP_Var Pnacl_M13_PPP_Selection_Dev_GetSelectedText(PP_Instance ins
iface->DeliverSamples(instance, audio_frames, decrypted_sample_info);
}
-/* End wrapper methods for PPB_ContentDecryptor_Private_0_10 */
+/* End wrapper methods for PPB_ContentDecryptor_Private_0_11 */
/* Begin wrapper methods for PPB_DisplayColorProfile_Private_0_1 */